@@ -1,8 +1,9 @@
-import time
+from browser_management import browser_sessions
 
 from seleniumtabs.exceptions import SeleniumRequestException
 from seleniumtabs.session import Session
 from seleniumtabs.tabs import Tab, TabManager
+from seleniumtabs.wait import humanized_wait
 
 
 class Browser:
@@ -33,6 +34,8 @@ class Browser:
         self._tabs = TabManager(self._session)
         self.full_screen = full_screen
 
+        browser_sessions.add_browser(self)
+
     def __enter__(self):
         return self
 
@@ -75,7 +78,7 @@ class Browser:
         if self._tabs.exist(tab):
             tab.switch()
             self._remove_tab(tab=tab)
-            time.sleep(1)
+            humanized_wait(1)
             self._tabs.switch_to_last_tab()
             return True
         else:
@@ -83,9 +86,13 @@ class Browser:
 
     def close(self):
         """Close browser"""
+        humanized_wait(1)
         self._tabs = {}
         self._session.close()
 
+    def __contains__(self, item: Tab):
+        return item in self.tabs
+
     def _remove_tab(self, tab: Tab):
         """For Internal Use Only: Closes a given tab.
 
@@ -181,7 +188,8 @@ if __name__ == "__main__":
 
         # Closing a tab
 
-        browser.close_tab(bing)
+        # browser.close_tab(bing)
+        bing.close()
         print(browser.tabs)
 
         assert bing.is_alive is False, err_msg  # noqa
@@ -209,7 +217,7 @@ if __name__ == "__main__":
         print(browser.current_tab)
         assert google == browser.current_tab, err_msg  # noqa
 
-        browser.close_tab(yahoo)
+        yahoo.close()
 
         print(yahoo.is_alive)
         print(yahoo.is_active)
@@ -218,10 +226,10 @@ if __name__ == "__main__":
         assert yahoo.is_alive is False, err_msg  # noqa
 
         # Accessing the driver object
-
         print(google.driver.title, google.title)
         assert google.driver.title == google.title, err_msg  # noqa
 
-        # Query using the powerful pyquery library
+        print(google.current_window_handle, google.tab_handle)
 
-        d = yahoo.pyquery  # noqa
+        # Query using the powerful pyquery library
+        d = google.pyquery  # noqa
