@@ -3,6 +3,7 @@ import random
 import time
 from collections import OrderedDict
 
+from browser_management import browser_sessions
 from browserjquery import BrowserJQuery
 from pyquery import PyQuery
 from selenium import webdriver
@@ -15,7 +16,7 @@ from selenium.webdriver.support.ui import WebDriverWait
 
 from seleniumtabs import settings
 from seleniumtabs.element_selectors import SelectableCSS
-from seleniumtabs.exceptions import SeleniumRequestException
+from seleniumtabs.exceptions import SeleniumOpenTabException, SeleniumRequestException
 from seleniumtabs.js_scripts import scripts
 from seleniumtabs.session import Session
 
@@ -58,11 +59,17 @@ class Tab:
 
     __repr__ = __str__
 
+    def __getattribute__(self, item):
+        with contextlib.suppress(Exception):
+            return super().__getattribute__(item)
+
+        return getattr(self.driver, item)
+
     def __del__(self):
-        pass
+        self.close()
 
     def __hash__(self):
-        return self.tab_handle
+        return hash(self.tab_handle)
 
     def __eq__(self, other: "Tab"):
         return self.tab_handle == other.tab_handle
@@ -142,8 +149,20 @@ class Tab:
     def open(self, url):
         """Open an url in the tab"""
 
-        self.driver.get(url)
-        return self
+        with contextlib.suppress(Exception):
+            self.driver.get(url)
+            return self
+
+        self.driver.execute_script(scripts.STOP_PAGE_LOADING)
+
+        if url in self.url or self.url in url:
+            logger.info(f"Page partially loaded: {self.url}")
+            return self
+
+        raise SeleniumOpenTabException("Could not open a new tab.")
+
+    def close(self):
+        browser_sessions.close_tab(self)
 
     def click(self, element: webelement.WebElement) -> bool:
         """Click a given element on the page represented by the tab"""
@@ -171,11 +190,12 @@ class Tab:
 
         self.switch()
 
-        height = random.randint(1, element.size["height"])
-        width = random.randint(1, element.size["width"])
+        height = random.randint(1, element.size["height"] // 2)
+        width = random.randint(1, element.size["width"] // 2)
 
         action = ActionChains(self.driver)
 
+        # offsets are measured from the centre of the element
         action.move_to_element_with_offset(element, width, height)
         action.click()
         action.perform()
@@ -352,6 +372,15 @@ class Tab:
 
         return PyQuery(self.page_html)
 
+    @property
+    def pq(self) -> PyQuery:
+        """Use the powerful pyquery on a Tab object.
+
+        http://pyquery.rtfd.org
+        """
+
+        return self.pyquery
+
 
 class TabManager:
     """A manager for multiple tabs associated with a browser"""
